nuketemplate
============

.. image:: https://img.shields.io/pypi/l/nuketemplate.svg
    :target: https://pypi.python.org/pypi/nuketemplate
.. image:: https://img.shields.io/pypi/pyversions/nuketemplate.svg
    :target: https://pypi.python.org/pypi/nuketemplate
.. image:: https://img.shields.io/pypi/v/nuketemplate.svg
    :target: https://pypi.python.org/pypi/nuketemplate
.. image:: https://img.shields.io/pypi/wheel/nuketemplate.svg
    :target: https://pypi.python.org/pypi/nuketemplate
.. image:: https://readthedocs.org/projects/nuketemplate/badge/?version=latest
    :target: https://readthedocs.org/projects/nuketemplate/?badge=latest

A toolkit to build Nuke scripts with flexible templates, based on Jinja 2

`Full Documentation`_

Installation
------------

To install ``nuketemplate``, type:

.. code-block:: bash

    $ pip install nuketemplate

Open Nuke's ``init.py`` file and add:

.. code-block:: python

    nuke.pluginAddPath('/path/to/your/local/python/site-packages')

Getting Started
---------------

Please see the `Getting Started`_ section of the documentation.

.. _Full Documentation: http://nuketemplate.readthedocs.io/en/latest/
.. _Getting Started: http://nuketemplate.readthedocs.io/en/latest/getting_started.html
